==> granite-server-3.0.0.GA-sources.jar: org/granite/messaging/amf/io/util/FieldProperty.java <==
/**
 *   GRANITE DATA SERVICES
 *   Copyright (C) 2006-2013 GRANITE DATA SERVICES S.A.S.
 *
 *   This file is part of the Granite Data Services Platform.
 *
 *   Granite Data Services is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   Granite Data Services is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 *   General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 *   USA, or see <http://www.gnu.org/licenses/>.
 */
package org.granite.messaging.amf.io.util;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.Type;

import org.granite.messaging.amf.io.convert.Converters;

/**
 * @author Franck WOLFF
 */
public class FieldProperty extends Property {

    private final Field field;

    public FieldProperty(Converters converters, Field field) {
        super(converters, field.getName());
        this.field = field;
    }

    @Override
    public boolean isAnnotationPresent(Class<? extends Annotation> annotationClass, boolean recursive) {
        return field.isAnnotationPresent(annotationClass);
    }

    @Override
	public <T extends Annotation> T getAnnotation(Class<T> annotationClass, boolean recursive) {
		return field.getAnnotation(annotationClass);
	}

	@Override
    public Type getType() {
        return field.getGenericType();
    }
	
	@Override
	public Class<?> getDeclaringClass() {
		return field.getDeclaringClass();
	}

    @Override
    public void setProperty(Object instance, Object value, boolean convert) {
        try {
            field.setAccessible(true);
            field.set(instance, convert ? convert(value) : value);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public Object getProperty(Object instance) {
        try {
            field.setAccessible(true);
            return field.get(instance);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}

==> granite-server-3.1.1.GA-sources.jar: org/granite/messaging/amf/io/util/FieldProperty.java <==
/**
 *   GRANITE DATA SERVICES
 *   Copyright (C) 2006-2014 GRANITE DATA SERVICES S.A.S.
 *
 *   This file is part of the Granite Data Services Platform.
 *
 *   Granite Data Services is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) any later version.
 *
 *   Granite Data Services is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 *   General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 *   USA, or see <http://www.gnu.org/licenses/>.
 */
package org.granite.messaging.amf.io.util;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.Type;

import org.granite.messaging.amf.io.convert.Converters;
import org.granite.messaging.amf.types.AMFSpecialValueFactory.SpecialValueFactory;

/**
 * @author Franck WOLFF
 */
public class FieldProperty extends Property {
	
    private final Field field;
    private final SpecialValueFactory<?> factory;

    public FieldProperty(Converters converters, Field field) {
        super(converters, field.getName());
        
        field.setAccessible(true);
        this.field = field;
        
        this.factory = specialValueFactory.getValueFactory(this);
    }

    @Override
    public boolean isAnnotationPresent(Class<? extends Annotation> annotationClass, boolean recursive) {
        return field.isAnnotationPresent(annotationClass);
    }

    @Override
	public <T extends Annotation> T getAnnotation(Class<T> annotationClass, boolean recursive) {
		return field.getAnnotation(annotationClass);
	}

	@Override
    public Type getType() {
        return field.getGenericType();
    }
	
	@Override
	public Class<?> getDeclaringClass() {
		return field.getDeclaringClass();
	}

    @Override
    public void setValue(Object instance, Object value, boolean convert) {
        try {
            field.set(instance, convert ? convert(value) : value);
        }
        catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public Object getValue(Object instance) {
        try {
            Object o = field.get(instance);
            if (factory != null)
            	o = factory.create(o);
            return o;
        }
        catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
